@@ -123,8 +123,9 @@ class AbstractInterface():
     receiver_match.remove()
 
   def __received_signal(self, key, *args, **kwargs):
-    try: value, mode, strength = getattr(self, 'process_signal_%s' % key)(*args, **kwargs)
-    except: pass
+    #try: 
+    value, mode, strength = getattr(self, 'process_signal_%s' % key)(*args, **kwargs)
+    #except Exception, e: print 'Error: ', e
     show_banner = False
     update_ui = False
     if value != None and value != self.state['value']:
